*
* Example from section 13.3, pp 390-397.
*
* You should use the data set available on the RATS
* web site. The one supplied with the book needs extra
* data before 1950 in order to supply lags for estimation.
*
open data tab135.xls
calendar 1947 1 4
data(format=xls,org=columns) 1947:01 1988:01 cons invest gnp rate govt gnet82 gnp82 m
*
set dy = gnp-gnp{1}
set dm = m-m{1}
set rsum = rate+rate{1}
*
* In order to simulate a model, we need to define formulas from
* the estimated equations. formulas (or FRML's) are descriptions of
* (possibly) non-linear relationships. Although this will end up
* being a fully linear system, it will be easier to set it up as
* if it were non-linear and let RATS work out the details.
*
* The easiest way to define a FRML is to include the FRML option on
* the instruction which estimates the equation. We've done this on
* the three LINREG instructions below.
*
smpl 1950:1 1985:4
linreg(frml=consf) cons
# constant gnp cons{1}
linreg(frml=investf) invest
# constant dy{1} gnp rate{4}
linreg(frml=ratef) rate
# constant gnp dy dm rsum{1}
*
* In addition, we need to define identities for those relationships
* involving the endogenous variables which aren't estimated. This
* includes the obvious one, which is the GNP accounting identity, but
* we also need "definitional" identities which describe how the
* constructed variables are related to the four endogenous variables
* of the system (c,i,y and r). Note that you don't have to define these
* for transformations of the exogenous variables; for instance, dm. A
* transformation of an exogenous variable is just another exogenous variable.
*
* FRML with the identity option is used to define the identities.
*
frml(identity) gnpf gnp  = cons+invest+govt
frml(identity) ydef dy   = gnp-gnp{1}
frml(identity) mdef dm   = m-m{1}
frml(identity) rdef rsum = rate+rate{1}
*
* Finally, we group the collection of estimated formulas and identities into
* a model. This is done using GROUP. The instruction below creates a model
* grouping known as olsmodel. consf>>simcons means to include the formula
* consf in the model, and to use simcons as the output series when any forecasts
* or simulations of this model are done. We create target series for the four
* real endogenous variables; we don't need them for the three transformation
* variables.
*
group olsmodel consf>>simcons investf>>siminv ratef>>simrate gnpf>>simgnp ydef mdef rdef
*
* This does the simulations. Since the SMPL was set to 1950:1 to 1985:4 above, we
* don't need to indicate a range.
*
forecast(model=olsmodel)
*
* We now graph the

graph(header='Figure 13.6 Historical Simulation of Consumption',$
   key=upleft,klabels=||'Actual','Simulated'||) 2
# cons
# simcons
graph(header='Figure 13.7 Historical Simulation of Investment',$
   key=upleft,klabels=||'Actual','Simulated'||) 2
# invest
# siminv
graph(header='Figure 13.8 Historical Simulation of Interest Rate',$
   key=upleft,klabels=||'Actual','Simulated'||) 2
# rate
# simrate
graph(header='Figure 13.9 Historical Simulation of GNP',$
   key=upleft,klabels=||'Actual','Simulated'||) 2
# gnp
# simgnp
*
@uforeerrors cons simcons
@uforeerrors invest siminv
@uforeerrors rate simrate
@uforeerrors gnp  simgnp
*
* Estimation by instrumental variables
*
smpl 1950:1 1985:4
instruments constant cons{1} dy{1} gnp{1} govt dm rsum{1} rate{4}
linreg(inst) cons
# constant gnp cons{1}
linreg(inst) invest
# constant dy{1} gnp rate{4}
*
* Cochrane-Orcutt applied to instrumental variables estimation requires
* an expansion of the instrument set to include the lagged dependent
* variable and lags of the regressors. (See, Fair's article in Econometrica,
* 1970). In this case, we don't need to include lags of both dy{1} and gnp,
* there would be a redundancy.
*
instruments constant cons{1} dy{1} gnp{1} govt dm rsum{1} rate{4}   invest{1} dy{2} rate{5}
ar1(method=corc,inst) invest
# constant dy{1} gnp rate{4}
*
* In this case, however, the Fair-CORC procedure converges to a local minimum
* rather than the global one. In fact, if a grid search procedure is used, the
* best fit is obtained with a rho very close to 1.
*
ar1(method=hilu,inst) invest
# constant dy{1} gnp rate{4}


